@@ -621,11 +621,14 @@ class Eniam():
             else:
                 if start_time is None:
                     start_time = time.time()
-                line_content = line.decode()
-                if (not collect_pdf) and (not collect_png):
-                    if line_content.find("LCG lexicon error") > -1:
-                        collect_err = True
-                    #print("=> "+line_content)
+                line_content = ""
+                try:
+                    line_content = line.decode()
+                except:
+                    line_content = ""
+                if line_content.find("LCG lexicon error") > -1:
+                    collect_err = True
+                #print("=> "+line_content)
                 if line_content.startswith("@done@"):
                     break
                 if collect_err:
